bayespy.inference.vmp.nodes.poisson.PoissonMoments
==================================================

.. currentmodule:: bayespy.inference.vmp.nodes.poisson

.. autoclass:: PoissonMoments

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~PoissonMoments.add_converter
      ~PoissonMoments.compute_dims_from_values
      ~PoissonMoments.compute_fixed_moments
      ~PoissonMoments.get_converter
   
   

   
   
   